<?php
/*
simple-gitv - a simple, libre web-based Git project viewer
Copyright (C) 2020

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

echo "\t\t<table width=\"100%\">\n";

// get files and directories in current path
$tree = list_files_verbose($git_dir, $path);

// separate into files and directories
$files = array();
$num_files = 0;
$directories = array();
$num_dirs = 0;
foreach($tree as $item) {
	$ind1 = strpos($item," ");
	$ind2 = strpos($item," ",$ind1+1);
	$type = substr($item,$ind1+1,$ind2-$ind1-1);
	
	$ind3 = strrpos($item,"\t");
	$name = substr($item,$ind3+1);
	if ($type === "tree") {
		$directories[$num_dirs] = after_last_slash($name);
		$num_dirs++;
	} else if ($type === "blob") {
		$files[$num_files] = after_last_slash($name);
		$num_files++;
	}
}

// TODO: add support for other branches?
$tree_path = "/$project/tree/$branch" . (empty($path) ? "" : "/$path");
$blob_path = "/$project/blob/$branch" . (empty($path) ? "" : "/$path");

// command to get latest commit for an item, formatted
$latest_commit_cmd = "git log -n 1 --pretty=format:\"\t\t\t\t<td><a href=\\\"/$project/commit/%H\\\">%s</a></td>\n\t\t\t\t<td><a href=\\\"/$project/commit/%H\\\">%ar</a></td>\n\" -- ";
if (!empty($path)) {
	$latest_commit_cmd = $latest_commit_cmd . "$path/";
}

// show directories first
foreach($directories as $dir) {
	echo "\t\t\t<tr class=\"dir\">\n";
	echo "\t\t\t\t<td><a href=\"$tree_path/$dir\">$dir</a></td>\n";
	$rows = explode("\n",shell_exec("cd $git_dir && $latest_commit_cmd$dir"));
	foreach ($rows as $row) {
		echo "$row\n";
	}
	echo "\t\t\t</tr>\n";
}

// show files second
foreach($files as $file) {
	echo "\t\t\t<tr class=\"file\">\n";
	echo "\t\t\t\t<td><a href=\"$blob_path/$file\">$file</a></td>\n";
	$rows = explode("\n",shell_exec("cd $git_dir && $latest_commit_cmd$file"));
	foreach ($rows as $row) {
		echo "$row\n";
	}
	echo "\t\t\t</tr>\n";
}
echo "\t\t</table>\n";
echo "\t\t<br/>\n\n";
?>
